@@ -24,7 +24,9 @@ fn trade() {
     }
     assert_eq!(
         1616486110921,
-        extract_timestamp("bitz", MarketType::Spot, raw_msg, None).unwrap()
+        extract_timestamp("bitz", MarketType::Spot, raw_msg)
+            .unwrap()
+            .unwrap()
     );
 
     assert_eq!(trades[0].side, TradeSide::Sell);
@@ -55,7 +57,9 @@ fn l2_orderbook_update() {
     );
     assert_eq!(
         1622527417489,
-        extract_timestamp("bitz", MarketType::Spot, raw_msg, None).unwrap()
+        extract_timestamp("bitz", MarketType::Spot, raw_msg)
+            .unwrap()
+            .unwrap()
     );
 
     assert_eq!(orderbook.timestamp, 1622527417489);
